Jido. VFS. RelativePath
(Jido.VFS v1.0.0)
Utilities for validating and normalizing relative filesystem paths.
Summary
Functions
Ensures the given path represents a directory path ending in /.
Expands . path segments and rejects parent traversal beyond the root.
Joins a storage prefix with a normalized relative path, preserving a trailing slash.
Normalizes a relative path and rejects absolute or traversal paths.
Returns true when the given path is relative for Unix and Windows path formats.
Removes a prefix from a fully-qualified storage path.
Types
@type t() :: Path.t()
Functions
Ensures the given path represents a directory path ending in /.
Expands . path segments and rejects parent traversal beyond the root.
Joins a storage prefix with a normalized relative path, preserving a trailing slash.
Normalizes a relative path and rejects absolute or traversal paths.
Returns true when the given path is relative for Unix and Windows path formats.
Removes a prefix from a fully-qualified storage path.